# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"Client": "client.ipynb",
         "getCardToken": "client.ipynb",
         "Keys": "helper.ipynb"}

modules = ["client.py",
           "helper.py"]

doc_url = "https://thanakijwanavit.github.io/globalPrimePay/"

git_url = "https://github.com/thanakijwanavit/globalPrimePay/tree/main/"

def custom_doc_links(name): return None



# AUTOGENERATED! DO NOT EDIT! File to edit: nbs/helper.ipynb (unless otherwise specified).

__all__ = ['Keys']

# Cell
import base64

# Cell

class Keys:

  def __init__(self, pub, secret, **kwargs):
    '''
    a key payload generator for global prime pay
    inputs:
      pub: str:: gpp public key from console
      secret: str:: gpp secret key from console
    '''
    self.pub = pub
    self.sec = secret
  @property
  def secPL(self):
    return self.keyPayload(self.sec + ":")
  @property
  def pubPL(self):
    return self.keyPayload(self.pub + ":")


  @staticmethod
  def keyPayload(key:str):
      return f'Basic {base64.b64encode(key.encode()).decode()}'


# AUTOGENERATED! DO NOT EDIT! File to edit: nbs/client.ipynb (unless otherwise specified).

__all__ = ['Client', 'getCardToken']

# Cell
from .helper import Keys
from nicHelper.wrappers import add_method
from numbers import Number
import requests

# Cell

class Client:
  '''
    main client for interface with global prime pay
  '''
  def __init__(self, pub, secret, endpoint = 'https://api.globalprimepay.com'):
    '''
      input:
        pub: str:: publiceKey from web
        secret: str:: secretKey from web
      docs (https://doc.gbprimepay.com)
    '''
    self.key = Keys(pub,secret)
    self.endpoint = endpoint


# Cell
@add_method(Client)
def getCardToken(self, cardNumber, expirationMonth, expirationYear, securityCode, name, **kwargs):

  body = {
    "rememberCard": True,
    "card": {
      "number": cardNumber,
      "expirationMonth": expirationMonth,
      "expirationYear": expirationYear,
      "securityCode": securityCode,
      "name": name
    }
    ,**kwargs
  }

  headersCharge = {
    'Authorization': self.key.pubPL,
    'Content-Type': 'application/json',
  }
  baseURL = self.endpoint
  url = f'{baseURL}/v2/tokens'
  r = requests.post(url,headers = headersCharge, json = body)
  return r.json()
